@@ -114,8 +114,12 @@ material_object.alpha = params["alpha"]
 bpy.context.scene.render.filepath = params["output_path"]
 bpy.context.scene.render.fps = params["fps"]
 #bpy.context.scene.render.quality = params["quality"]
-bpy.context.scene.render.file_format = params["file_format"]
-bpy.context.scene.render.color_mode = params["color_mode"]
+try:
+	bpy.context.scene.render.file_format = params["file_format"]
+	bpy.context.scene.render.color_mode = params["color_mode"]
+except:
+	bpy.context.scene.render.image_settings.file_format = params["file_format"]
+	bpy.context.scene.render.image_settings.color_mode = params["color_mode"]
 bpy.data.worlds[0].horizon_color = params["horizon_color"]
 bpy.context.scene.render.resolution_x = params["resolution_x"]
 bpy.context.scene.render.resolution_y = params["resolution_y"]
