@@ -20,6 +20,7 @@ import effect, copy
 import os, locale, uuid
 import xml.dom.minidom as xml
 import gtk, goocanvas
+import re
 from classes.keyframe import keyframe
 
 ########################################################################
@@ -340,9 +341,14 @@ class clip:
 			if self.parent == MyTrack:
 				self.GenerateXML(dom, playlist, current_frame=0, preview_mode=preview_mode, fps=fps)
 
+		# Pretty print using a Regular expression (I am using regex due to a bug in the minidom, with extra 
+		# whitespace in it's pretty print method.  This should fix the pretty print's white space issue.)
+		pretty_print = re.compile(r'((?<=>)(\n[\t]*)(?=[^<\t]))|((?<=[^>\t])(\n[\t]*)(?=<))')
+		pretty_print_output = re.sub(pretty_print, '', dom.toprettyxml())
+
 		# Save the XML dom
 		f = open(file_name, "w")
-		dom.writexml(f, encoding=encoding)
+		f.write(pretty_print_output)
 		f.close()
 
 
@@ -445,6 +451,12 @@ class clip:
 			if self.reversed:
 				# add a negative sign
 				speed_string = "-" + speed_string
+				
+				# Update producer (adjust IN and OUT points... because the entire clip is reversed)
+				if self.file_object.file_type == "video":
+					clip_length_in_frames = round(self.max_length * fps) - 1
+					producer.setAttribute("in", str(clip_length_in_frames - int(round(out_frame_number))))
+					producer.setAttribute("out", str(clip_length_in_frames - int(round(in_frame_number))))
 
 			# update resource speed
 			resource_name = resource_name + "?" + speed_string
