@@ -30,27 +30,44 @@ def save_project(project_object, file_path):
 			# create new thumbnail folder
 			os.mkdir(os.path.join(project_object.folder, "thumbnail"))
 			
-		# copy all temp thumbnails to this project's folder
-		copy_files(os.path.join(project.USER_DIR, "thumbnail"), os.path.join(project_object.folder, "thumbnail"))
+		# copy all temp thumbnails to this project's folder (if it's different)
+		if project.USER_DIR != project_object.folder:
+			# different path, so copy thumbnails, adjust paths
+			copy_files(os.path.join(project.USER_DIR, "thumbnail"), os.path.join(project_object.folder, "thumbnail"))
 
-		# Loop through the files, and update the thumbnail location
-		for item in project_object.project_folder.items:
-			
-			if isinstance(item, files.OpenShotFile):
-
-				# split thumbnail file path
-				(dirName, fname) = os.path.split(item.thumb_location)
-				(fileBaseName, fileExtension)=os.path.splitext(fname)
-	
-				# update the thumbnail location
-				item.thumb_location = os.path.join(project_object.folder, "thumbnail", fname)
+			# Loop through the files, and update file path for images and image sequences
+			for item in project_object.project_folder.items:
 				
-				# UPDATE TITLES... so they move with the project
-				# update the thumbnail location
-				if ".svg" in item.name and "thumbnail" in item.name:
+				# Is this item a File (i.e. ignore folders)
+				if isinstance(item, files.OpenShotFile):
+	
+					# Get file path info for this item
 					(dirName, fname) = os.path.split(item.name)
-					(fileBaseName, fileExtension)=os.path.splitext(fname)
-					item.name = os.path.join(project_object.folder, "thumbnail", fname)
+					(thumbdirName, thumbfname) = os.path.split(item.thumb_location)
+	
+					# Update the thumbnail location
+					item.thumb_location = os.path.join(project_object.folder, "thumbnail", thumbfname)
+					
+					# if image sequence and in the .openshot folder
+					if item.file_type == "image sequence" and project.USER_DIR in item.name:
+						# Determine folder name of image sequence 
+						(rootFolder, blenderFolderName) = os.path.split(dirName)
+						
+						# create new folder (if needed)
+						if os.path.exists(os.path.join(project_object.folder, blenderFolderName)) == False:
+							# create new thumbnail folder
+							os.mkdir(os.path.join(project_object.folder, blenderFolderName))
+						
+						# Copy files to new project folder
+						copy_files(dirName, os.path.join(project_object.folder, blenderFolderName))
+						
+						# Update Path to Image Sequence
+						item.name = os.path.join(project_object.folder, blenderFolderName, fname)
+					
+					elif item.file_type == "image" and ".svg" in item.name and "thumbnail" in item.name:
+						# UPDATE TITLES... so they move with the project
+						item.name = os.path.join(project_object.folder, "thumbnail", fname)
+					
 
 
 		# clear the following temporary properties which can't be pickeled
