@@ -176,7 +176,11 @@ class thumbnailer ( threading.Thread ):
 				# mark as image seq
 				self.label = "Image Sequence"
 				self.file_type = "image sequence"
-			
+
+			# Check if clip is valid (otherwise a seg fault)
+			if self.p.is_valid() == False:
+				return None
+
 			# connect the producer and consumer
 			self.c.connect( self.p )
 
@@ -238,9 +242,10 @@ class thumbnailer ( threading.Thread ):
 		self.profile = None
 		self.f = None
 		
-	def get_thumb_at_frame(self, filename, frame=1, new_name=""):
-		'''by passing a value in new_name, this will extract a 
-		 full size frame (based on the project profile).'''
+	def get_thumb_at_frame(self, filename, frame=1, new_name="", full_size=True):
+		""" if new_name = None, it will default to  'name_fileext + "_%d.ext' in the thumbnail folder.
+		if full_size is True, a full size frame will be extracted (based on the project profile).
+		Else: quarter_ntsc"""
 		
 		self.file_name = filename
 		
@@ -254,10 +259,10 @@ class thumbnailer ( threading.Thread ):
 		mlt.Factory.init()
 		
 		# set the profile
-		if new_name == "":
-			self.profile = mlt.Profile("quarter_ntsc")
-		else:
+		if full_size:
 			self.profile = profiles.mlt_profiles(self.project).get_profile(self.project.project_type)
+		else:
+			self.profile = mlt.Profile("quarter_ntsc")
 		
 		# Create the producer
 		self.p = mlt.Producer( self.profile, '%s' % self.file_name )
@@ -284,6 +289,10 @@ class thumbnailer ( threading.Thread ):
 		
 		#get the frame
 		self.p = self.p.cut(frame, frame)
+
+		# Check if clip is valid (otherwise a seg fault)
+		if self.p.is_valid() == False:
+			return None
 		
 		# connect the producer and consumer
 		self.c.connect( self.p )
