@@ -16,7 +16,7 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
-import os, sys, time 
+import os, sys, locale, time
 import threading
 import gobject
 from classes import profiles
@@ -155,7 +155,7 @@ class player ( threading.Thread ):
 					self.c.set("qmax", "51")
 					self.c.set("subq", "7")
 					self.c.set("qmin", "10")
-					self.c.set("qcomp", "0.6")
+					self.c.set("qcomp", locale.str(float("0.6")))
 					self.c.set("qdiff", "4")
 					self.c.set("trellis", "1")
 				if format == "dvd":
