@@ -55,27 +55,70 @@ class frmAddFiles(SimpleGtkBuilderApp):
 	def on_btnAdd_clicked(self, widget, *args):
 		files_to_add = self.frmAddFiles.get_filenames()
 		
+		# get a reference to the language translate method
+		_ = self.project.translate
+		
 		# create a unique session id, to prevent duplicate prompts
 		session = str(time.time())
 		
+		# The total number of ok files selected (not folders)
+		total_ok_files = 0
+		# The total number of broken files selected (could not be imported)
+		total_broken_files = 0
+		# The total number of files already imported selected
+		total_duplicate_files = 0
+		# The total number of folders selected
+		total_folders = 0
+		
 		try:
 			for file in files_to_add:
 				# add each file
-				self.project.project_folder.AddFile(file, session=session)
+				result = self.project.project_folder.AddFile(file, session=session)
+				# parse the results and add to the total
+				total_ok_files += result[0]
+				total_broken_files += result[1]
+				total_duplicate_files += result[2]
+				total_folders += result[3]
+		
+			# The number of total selected files, not including folders
+			total_files = total_ok_files + total_broken_files + total_duplicate_files
+		
+			# print error messages (if needed)
+		
+			if total_files == 0:
+				if total_folders == 1:
+					messagebox.show(_("Empty Folder "), _("The selected folder was empty."))
+				else:
+					messagebox.show(_("Empty Folders"), _("The selected folders were empty."))
+			else:
+				if total_files == total_broken_files:
+					if total_files == 1:
+						messagebox.show(_("Unsupported File Type"), _("OpenShot does not support this file type."))
+					else:
+						messagebox.show(_("Unsupported File Types"), _("OpenShot supports none of the file types of the selected files."))
 			
-			#set the project as modified
+				elif total_files == total_duplicate_files:
+					if total_files == 1:
+						messagebox.show(_("Already Imported File"), _("The selected file has already been imported to the project."))
+					else:
+						messagebox.show(_("Already Imported Files"), _("All of the selected files have already been imported to the project."))
+			
+				elif total_ok_files == 0:
+					messagebox.show(_("File Import Error"), _("The selected files either have an unsupported file type or have already been imported to the project."))
+					
+			# set the project as modified
 			self.project.set_project_modified(is_modified=True, refresh_xml=False)
-				
+			
 			# refresh the main form
 			self.form.refresh_files()
 			
 		except:
-			messagebox.show(_("Error"), _("There was an error importing the selected files"))
+			messagebox.show(_("Error"), _("There was an error importing the selected file(s)."))
 
 		#set the last used folder
 		preferences.Settings.app_state["import_folder"] = self.frmAddFiles.get_current_folder()
 		
-		# clear and destory this dialog
+		# clear and destroy this dialog
 		self.form.import_files_dialog = None	
 		self.frmAddFiles.destroy()
 		
@@ -117,7 +160,7 @@ class frmReplaceFiles(SimpleGtkBuilderApp):
 			self.form.replace_clip(self.clip,replace_clip_with)
 			
 		except:
-			messagebox.show(_("Error"), _("There was an error importing the selected files"))
+			messagebox.show(_("Error"), _("There was an error importing the selected file(s)."))
 
 		#set the last used folder
 		preferences.Settings.app_state["import_folder"] = self.frmAddFiles.get_current_folder()
