@@ -81,8 +81,13 @@ class frmAddToTimeline(SimpleGtkBuilderApp):
 		file_list = os.listdir(os.path.join(self.project.TRANSITIONS_DIR))
 
 		for fname in sorted(file_list):
+			
 			(dirName, file_name) = os.path.split(fname)
 			(fileBaseName, fileExtension)=os.path.splitext(file_name)
+			
+			if fname == "icons":
+				# ignore the 'icons' folder
+				continue
 
 			# get name of transition
 			trans_name = fileBaseName.replace("_", " ").capitalize()
