@@ -19,6 +19,7 @@
 import os, time, uuid, shutil
 import gobject, threading, subprocess, re
 import gtk
+import math
 import subprocess
 from windows.SimpleGtkBuilderApp import SimpleGtkBuilderApp
 from windows import preferences, TreeBlender
@@ -201,6 +202,8 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 				# create hbox and label
 				hbox = gtk.HBox(False, 0)
 				label = gtk.Label("")
+				self.sizegroup1.add_widget(label)
+				label.set_alignment(0, 0.5)
 				hbox.pack_start(label, False, True, 10)
 				self.vbox_settings.pack_start(hbox, False, False, 5)
 				self.vbox_settings.show_all()
@@ -281,9 +284,13 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 					colorButton.set_color(default_color)	
 					color = colorButton.get_color()
 					
+					# adjust gamma values for Blender
+					r = math.pow(color.red_float, 2.2)
+					g = math.pow(color.green_float, 2.2)
+					b = math.pow(color.blue_float, 2.2)
+					
 					# add value to dictionary
-					#self.params[param.name] = [color.red/255, color.green/255, color.blue/255]
-					self.params[param.name] = [color.red_float, color.green_float, color.blue_float]
+					self.params[param.name] = [r, g, b]
 
 					# connect signal
 					colorButton.connect("color-set", self.effect_color_changed, real_effect, param)
@@ -346,9 +353,13 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		# Get color from color picker
 		color = widget.get_color()
 		
-		# Update the param of the selected effect
-		#self.params[param.name] = [color.red/255, color.green/255, color.blue/255]
-		self.params[param.name] = [color.red_float, color.green_float, color.blue_float]
+		# adjust gamma values for Blender
+		r = math.pow(color.red_float, 2.2)
+		g = math.pow(color.green_float, 2.2)
+		b = math.pow(color.blue_float, 2.2)
+		
+		# add value to dictionary
+		self.params[param.name] = [r, g, b]
 		
 		
 	def html_color(self, color):
@@ -627,8 +638,15 @@ class frm3dGenerator(SimpleGtkBuilderApp):
 		length = end_frame - start_frame
 			
 		# add file to current project
-		f = self.project.project_folder.AddFile(first_image, ignore_image_sequences=True)
+		#f = self.project.project_folder.AddFile(first_image, ignore_image_sequences=True)
+		f = self.project.thumbnailer.GetFile(first_image)
 		
+		if f:
+			self.project.project_folder.items.append(f)
+			
+		# mark project as modified
+		self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Added file"))
+			
 		# Update the file properties (since it's added as an image)
 		# We need to make it look like a video
 		f.label = _("Image Sequence")
