@@ -968,6 +968,9 @@ class frmClipProperties(SimpleGtkBuilderApp):
 		# Apply settings to preview clip object
 		self.apply_settings(self.copy_of_clip)
 
+		# Set clip to position 0 seconds
+		self.copy_of_clip.position_on_track = 0.0
+
 		# Generate the Preview XML
 		self.copy_of_clip.GeneratePreviewXML(os.path.join(self.project.USER_DIR, "preview.mlt"), "clip-properties-preview")
 
