@@ -610,6 +610,8 @@ class frmExportVideo(SimpleGtkBuilderApp):
 		# get correct gettext method
 		_ = self._
 		
+		
+		
 		# determine if we are UPLOADING or EXPORTING		
 		export_type = self.cboExportType.get_active_text()
 		if export_type == _("Upload to Web"):
@@ -621,6 +623,9 @@ class frmExportVideo(SimpleGtkBuilderApp):
 			localfileExportFolder = str.strip(self.fileExportFolder.get_filename())
 			localtxtFileName = str.strip(self.txtFileName.get_text())
 		
+		# replace any directory separator characters from the filename
+		localtxtFileName = localtxtFileName.replace('/', '_')
+			
 		# Get general settings
 		localcboExportTo = self.cboExportTo.get_active_text()
 		
@@ -718,6 +723,15 @@ class frmExportVideo(SimpleGtkBuilderApp):
 			self.render_options["ar"] = localtxtSampleRate
 			self.render_options["ac"] = localtxtChannels
 			self.render_options["ab"] = AudioBitRateBytes
+			
+			#check the webm render options are correct - webm can only handle
+			#libvorbis and libvpx.
+			if localtxtVideoFormat == 'webm' and (localtxtAudioCodec != 'libvorbis' or localtxtVideoCodec != 'libvpx'):
+				#override the codecs for webm to prevent a libavformat crash.
+				print "Invalid WebM codec detected, forcing WebM defaults"
+				self.render_options["acodec"] = 'libvorbis'
+				self.render_options["vcodec"] = 'libvpx'
+				
 
 			# get the complete path to the new file
 			folder1 = self.render_options["folder"]
@@ -731,7 +745,6 @@ class frmExportVideo(SimpleGtkBuilderApp):
 				# no existing file, so export now
 				self.do_export()
 
-			 
 	def do_export(self):
 		
 		#gray out the export window
