@@ -91,7 +91,7 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		
 			
 		#populate form objects
-		self.valImageLength.set_value(float(self.form.settings.general["imported_image_length"]))
+		self.valImageLength.set_value(float(self.form.settings.general["imported_image_length"].replace(",",".")))
 		self.valHistoryStackSize.set_value(float(self.form.settings.general["max_history_size"]))
 		self.txtMeltCommandName.set_text(self.form.settings.general["melt_command"])
 		self.txtBlenderCommand.set_text(self.form.settings.general["blender_command"])
@@ -200,7 +200,7 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		
 	def on_btnClose_clicked(self, widget, *args):
 		#write the values from the form to the dictionary objects
-		self.form.settings.general["imported_image_length"] = self.valImageLength.get_text()
+		self.form.settings.general["imported_image_length"] = self.valImageLength.get_text().replace(",",".")
 		self.form.settings.general["default_theme"] = self.cmbThemes.get_active_text()
 		self.form.settings.general["default_profile"] = self.cmbProfiles.get_active_text()
 		self.form.settings.general["melt_command"] = self.txtMeltCommandName.get_text()
@@ -214,7 +214,7 @@ class PreferencesMgr(SimpleGtkBuilderApp):
 		self.frmPreferences.destroy()
 		
 	def on_valImageLength_value_changed(self, widget, *args):
-		self.form.settings.general["imported_image_length"] = self.valImageLength.get_value_as_int()
+		self.form.settings.general["imported_image_length"] = self.valImageLength.get_text().replace(",",".")
 		
 	def on_cmbProfiles_changed(self, widget, *args):
 		self.form.settings.general["default_profile"] = self.cmbProfiles.get_active_text()
